#!/bin/sh
#v.1.0.1 10.05.2005 by ruDREAM
#profile for radegast
case $1 in
start)
rdgd &
sleep 3
netpilot 127.0.0.1 666 &
sleep 2
camd.rdgd &
sleep 2
;;
during)
;;
stop)
killall -9 camd.rdgd
killall -9 netpilot
killall -9 rdgd
sleep 1
;;
esac
exit 0
